@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.02.
 package Apache::Solr;
 use vars '$VERSION';
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 
 use warnings;
@@ -391,7 +391,8 @@ sub expandExtract(@)
 }
 
 
-my %sets =   #also-per-field?  (probably more config later)
+# probably more config later, currently only one column
+my %sets =   #also-per-field?
   ( facet => [1]
   , hl    => [1]
   , mlt   => [0]
@@ -414,9 +415,10 @@ sub expandSelect(@)
 
         if(my $def = $sets{$set})
         {   $seen_set{$set} = 1;
-            $def->[0]
+            !$per_field || $def->[0]
                or error __x"set {set} cannot be used per field, in {field}"
                     , set => $set, field => $k;
+
             if(ref $v eq 'HASH')
             {   !$more
                     or error __x"field {field} is not simple for a set", field => $k;
